@@ -1,4 +1,5 @@
 """Task database model"""
+import json
 import uuid
 
 from pathlib import Path
@@ -42,14 +43,13 @@ class Task(Base):
 
     SQLAlchemy declarative model for the tasks3 database containing tasks.
 
-    Attributes:
-        id: Unique ID for the task.
-        title: Title of the task.
-        urgency: Urgency level[0-4] of the task.
-        importance: Importance level[0-4] of the task.
-        tags: Set of tags to apply to the task.
-        folder: Anchor this task to a particular directory or file.
-        description: Description of the task.
+    :param id: Unique ID for the task.
+    :param title: Title of the task.
+    :param urgency: Urgency level[0-4] of the task.
+    :param importance: Importance level[0-4] of the task.
+    :param tags: Set of tags to apply to the task.
+    :param folder: Anchor this task to a particular directory or file.
+    :param description: Description of the task.
     """
 
     title = Column(Unicode, nullable=False)
@@ -116,6 +116,7 @@ class Task(Base):
         return rep
 
     def yaml(self) -> str:
+        """YAML representation of the task"""
         top = (
             f"title: {self.title}\n"
             f"urgency: {self.urgency}\n"
@@ -131,5 +132,9 @@ class Task(Base):
             yaml += f"description: >-\n  {description}\n"
         return yaml
 
+    def json(self) -> str:
+        """JSON representation of the task"""
+        return json.dumps(self.to_dict(), indent=2)
+
     def __repr__(self) -> str:
         return f"<Task{self.to_dict().__repr__()}>"
